# coding: utf-8

"""
POE New Relic

Module containing a class for interacting with the New Relic's Nerdgraph API.   # noqa: E501
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "poe_new_relic"
VERSION = "0.1.3"
REQUIRES = ["requests"]

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

setup(
    name=NAME,
    version=VERSION,
    description="POE New Relic",
    author="Pearson Observability Engineering",
    author_email="TOIOServiceWorkflowAutomation@grp.pearson.com",
    url="https://github.com/orgs/pearson-digitalandtechnology/POE-python-packages",
    keywords=["Pearson", "POE", "POE New Relic", "New Relic"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
     Module containing a class for interacting with the New Relic's Nerdgraph API.   # noqa: E501
    """,
)
